@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for GNU Prolog 1.4.5 (and later versions)
-%  Last updated on August 5, 2020
+%  Last updated on September 10, 2020
 %
 %  This file is part of Logtalk <https://logtalk.org/>
 %  Copyright 1998-2020 Paulo Moura <pmoura@logtalk.org>
@@ -153,6 +153,7 @@ setup_call_cleanup(_, _, _) :-
 '$lgt_candidate_tautology_or_falsehood_goal_hook'(list_or_partial_list(_)).
 '$lgt_candidate_tautology_or_falsehood_goal_hook'(name(_, _)).
 '$lgt_candidate_tautology_or_falsehood_goal_hook'(partial_list(_)).
+'$lgt_candidate_tautology_or_falsehood_goal_hook'(succ(_, _)).
 
 
 % '$lgt_prolog_database_predicate'(@callable)
@@ -464,10 +465,10 @@ setup_call_cleanup(_, _, _) :-
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 
-% '$lgt_read_term'(@stream, -term, +list, -position, -list)
+% '$lgt_read_term'(@stream, -term, +list, -pair(integer,integer))
 
-'$lgt_read_term'(Stream, Term, Options, LineBegin-LineEnd, Variables) :-
-	read_term(Stream, Term, [syntax_error(error), variable_names(Variables)| Options]),
+'$lgt_read_term'(Stream, Term, Options, LineBegin-LineEnd) :-
+	read_term(Stream, Term, [syntax_error(error)| Options]),
 	last_read_start_line_column(LineBegin, _),
 	stream_line_column(Stream, Line, Col),
 	(	Col = 1 ->
@@ -588,6 +589,11 @@ setup_call_cleanup(_, _, _) :-
 	use_module(_, _) :- fail.
 :- endif.
 
+asserta(_, _) :- fail.
+assertz(_, _) :- fail.
+clause(_, _, _) :- fail.
+erase(_) :- fail.
+
 mutex_create(_, _) :- fail.
 mutex_lock(_) :- fail.
 mutex_property(_, _) :- fail.
