@@ -3,7 +3,7 @@
 #############################################################################
 ## 
 ##   Logtalk backend Prolog compiler select script
-##   Last updated on June 5, 2020
+##   Last updated on October 4, 2020
 ## 
 ##   This file is part of Logtalk <https://logtalk.org/>  
 ##   Copyright 1998-2020 Paulo Moura <pmoura@logtalk.org>
@@ -25,7 +25,7 @@
 
 print_version() {
 	echo "Current $(basename "$0") version:"
-	echo "  0.8"
+	echo "  0.9"
 	exit 0
 }
 
@@ -35,6 +35,9 @@ list_backends() {
 	if [ -e "$(command -v bplgt)" ] && [ "$(command -v bp)" != "" ] ; then
 		echo -n "  bplgt"
 	fi
+	if [ -e "$(command -v ciaolgt)" ] && [ "$(command -v ciaosh)" != "" ] ; then
+		echo -n "  ciaolgt"
+	fi
 	if [ -e "$(command -v cxlgt)" ] && [ "$(command -v cxprolog)" != "" ] ; then
 		echo -n "  cxlgt"
 	fi
@@ -47,6 +50,9 @@ list_backends() {
 	if [ -e "$(command -v jiplgt)" ] && [ "$(command -v jipconsole.sh)" != "" ] ; then
 		echo -n "  jiplgt"
 	fi
+	if [ -e "$(command -v lvmlgt)" ] && [ "$(command -v lvm)" != "" ] ; then
+		echo -n "  lvmlgt"
+	fi
 	if [ -e "$(command -v qplgt)" ] && [ "$(command -v qp)" != "" ] ; then
 		echo -n "  qplgt"
 	fi
@@ -56,6 +62,9 @@ list_backends() {
 	if [ -e "$(command -v swilgt)" ] && [ "$(command -v swipl)" != "" ] ; then
 		echo -n "  swilgt"
 	fi
+	if [ -e "$(command -v taulgt)" ] && [ -d "$NODE_PATH/tau-prolog" ] ; then
+		echo -n "  taulgt"
+	fi
 	if [ -e "$(command -v xsblgt)" ] && [ "$(command -v xsb)" != "" ] ; then
 		echo -n "  xsblgt"
 	fi
@@ -124,6 +133,8 @@ usage_help() {
 valid_backend() {
 	if [ "$1" == "bplgt" ] && [ -e "$(command -v bplgt)" ]  && [ "$(command -v bp)" != "" ] ; then
 		return 0
+	elif [ "$1" == "ciaolgt" ] && [ -e "$(command -v ciaolgt)" ]  && [ "$(command -v ciaosh)" != "" ] ; then
+		return 0
 	elif [ "$1" == "cxlgt" ] && [ -e "$(command -v cxlgt)" ]  && [ "$(command -v cxprolog)" != "" ] ; then
 		return 0
 	elif [ "$1" == "eclipselgt" ] && [ -e "$(command -v eclipselgt)" ]  && [ "$(command -v eclipse)" != "" ] ; then
@@ -132,7 +143,7 @@ valid_backend() {
 		return 0
 	elif [ "$1" == "jiplgt" ] && [ -e "$(command -v jiplgt)" ]  && [ "$(command -v jipconsole.sh)" != "" ] ; then
 		return 0
-	elif [ "$1" == "lplgt" ] && [ -e "$(command -v lplgt)" ]  && [ "$(command -v lprolog)" != "" ] ; then
+	elif [ "$1" == "lvmlgt" ] && [ -e "$(command -v lvmlgt)" ]  && [ "$(command -v lvm)" != "" ] ; then
 		return 0
 	elif [ "$1" == "qplgt" ] && [ -e "$(command -v qplgt)" ]  && [ "$(command -v qp)" != "" ] ; then
 		return 0
@@ -140,6 +151,8 @@ valid_backend() {
 		return 0
 	elif [ "$1" == "swilgt" ] && [ -e "$(command -v swilgt)" ]  && [ "$(command -v swipl)" != "" ] ; then
 		return 0
+	elif [ "$1" == "taulgt" ] && [ -e "$(command -v taulgt)" ] && [ -d "$NODE_PATH/tau-prolog" ] ; then
+		return 0
 	elif [ "$1" == "xsblgt" ] && [ -e "$(command -v xsblgt)" ]  && [ "$(command -v xsb)" != "" ] ; then
 		return 0
 	elif [ "$1" == "xsbmtlgt" ] && [ -e "$(command -v xsbmtlgt)" ]  && [ "$(command -v xsb-mt)" != "" ] ; then
