@@ -3,7 +3,7 @@
 #############################################################################
 ## 
 ##   Unit testing automation script
-##   Last updated on August 26, 2020
+##   Last updated on October 24, 2020
 ## 
 ##   This file is part of Logtalk <https://logtalk.org/>  
 ##   Copyright 1998-2020 Paulo Moura <pmoura@logtalk.org>
@@ -25,7 +25,7 @@
 # loosely based on a unit test automation script contributed by Parker Jones
 
 print_version() {
-	echo "$(basename "$0") 2.3"
+	echo "$(basename "$0") 2.8"
 	exit 0
 }
 
@@ -46,9 +46,9 @@ if [[ "$(command -v timeout)" == *"System32"* ]] || [[ "$(command -v timeout)" =
 	timeout_command=""
 # second, look for GNU coreutils package timeout command
 elif [ -x "$(command -v timeout)" ] && [[ "$(timeout --version)" == *"GNU coreutils"* ]] ; then
-	timeout_command="timeout -k 1"
+	timeout_command="timeout -s 9 -k 1.0s"
 elif [ -x "$(command -v gtimeout)" ] && [[ "$(gtimeout --version)" == *"GNU coreutils"* ]] ; then
-	timeout_command="gtimeout -k 1"
+	timeout_command="gtimeout -s 9 -k 1.0s"
 else
 	timeout_command=""
 fi
@@ -67,6 +67,7 @@ format='default'
 coverage='none'
 flag_goal="true"
 initialization_goal="true"
+wipe='false'
 # disable timeouts to maintain backward compatibility
 timeout=0
 prefix="$HOME/"
@@ -91,6 +92,10 @@ run_testset() {
 	unit=$(dirname "$1")
 	unit_short=${unit#$prefix}
 	cd "$unit" || exit 1
+	if [ "$wipe" == 'true' ] ; then
+		rm -rf ./.lgt_tmp
+		rm -rf ./lgt_tmp
+	fi
 	if [ "$output" == 'verbose' ] ; then
 		echo "%"
 		echo "% $unit_short"
@@ -122,7 +127,12 @@ run_testset() {
 		tests_exit=$?
 		mode_prefix="% (debug) "
 	fi
-	if [ $tests_exit -eq 0 ] && [ -f "$results/$name.totals" ] && [ "$output" == 'verbose' ] ; then
+
+	if [ $tests_exit -eq 0 ] && [ "$output" == 'verbose' ] && grep -q "tests skipped" "$results/$name.results" ; then
+		echo "%         skipped"
+	elif [ $tests_exit -eq 0 ] && [ "$output" == 'verbose' ] && grep -q "(not applicable)" "$results/$name.results" ; then
+		echo "%         not applicable"
+	elif [ $tests_exit -eq 0 ] && [ -f "$results/$name.totals" ] && [ "$output" == 'verbose' ] ; then
 		while read -r line ; do
 			echo -n "$mode_prefix"
 			echo -n "$(cut -f 3 <<< "$line")"
@@ -138,9 +148,11 @@ run_testset() {
 		done < <(grep '^object' "$results/$name.totals")
 		echo -n '%         clause coverage '
 		echo "$(grep "^coverage" "$results/$name.totals" | cut -f 2)"
-	elif [ $tests_exit -eq 0 ] && [ "$output" == 'verbose' ] ; then
-		grep -a '(not applicable)' "$results/$name.results" | $sed 's/(/%         (/'
-	elif [ $tests_exit -eq 124 ] ; then
+	elif [ $tests_exit -eq 5 ] ; then
+		if [ "$output" == 'verbose' ] ; then
+			echo "%         broken"
+		fi
+	elif [ $tests_exit -eq 137 ] ; then
 		if [ "$output" == 'verbose' ] ; then
 			echo "%         timeout"
 		fi
@@ -181,10 +193,8 @@ run_tests() {
 	fi
 	exit=$?
 	if [ $exit -eq 0 ] && ! grep -q "(not applicable)" "$results/$name.results" && ! grep -q -s "^object" "$results/$name.totals" && ! grep -q "tests skipped" "$results/$name.results"; then
-		if [ "$output" == 'verbose' ] ; then
-			echo "%         broken"
-		fi
 		echo "LOGTALK_BROKEN" >> "$results/$name.errors"
+		return 5
 	fi
 	return $exit
 }
@@ -200,7 +210,7 @@ usage_help()
 	echo "The \"tester.sh\" file is sourced with all the parameters passed to the script."
 	echo
 	echo "Usage:"
-	echo "  $(basename "$0") [-o output] [-p prolog] [-m mode] [-f format] [-d results] [-t timeout] [-n driver] [-s prefix] [-c report] [-l level] [-i options] [-g goal] [-r seed] [-- arguments]"
+	echo "  $(basename "$0") [-o output] [-p prolog] [-m mode] [-f format] [-d results] [-t timeout] [-n driver] [-s prefix] [-c report] [-l level] [-i options] [-g goal] [-r seed] [-w] [-- arguments]"
 	echo "  $(basename "$0") -v"
 	echo "  $(basename "$0") -h"
 	echo
@@ -208,7 +218,7 @@ usage_help()
 	echo "  -v print version of $(basename "$0")"
 	echo "  -o output (valid values are verbose and minimal; default is $output)"
 	echo "  -p backend Prolog compiler (default is $backend)"
-	echo "     (valid values are b, ciao, cx, eclipse, gnu, ji, qp, sicstus, swi, swipack, tau, xsb, xsbmt, and yap)"
+	echo "     (valid values are b, ciao, cx, eclipse, gnu, ji, lvm, qp, sicstus, swi, swipack, tau, xsb, xsbmt, and yap)"
 	echo "  -m compilation mode (default is $mode)"
 	echo "     (valid values are optimal, normal, debug, and all)"
 	echo "  -f format for writing the test results (default is $format)"
@@ -224,12 +234,13 @@ usage_help()
 	echo "  -i integration script command-line options (no default)"
 	echo "  -g initialization goal (default is $initialization_goal)"
 	echo "  -r random generator starting seed (no default)"
+	echo "  -w wipe default scratch directories (./.lgt_tmp and ./lgt_tmp) before running a test set"
 	echo "  -- arguments to be passed to the tests (no default)"
 	echo "  -h help"
 	echo
 }
 
-while getopts "vo:p:m:f:d:t:n:s:c:l:g:r:i:h" option
+while getopts "vo:p:m:f:d:t:n:s:c:l:g:r:i:wh" option
 do
 	case $option in
 		v) print_version;;
@@ -246,6 +257,7 @@ do
 		i) i_arg="$OPTARG";;
 		g) g_arg="$OPTARG";;
 		r) r_arg="$OPTARG";;
+		w) wipe='true';;
 		h) usage_help; exit;;
 		*) usage_help; exit;;
 	esac
@@ -300,6 +312,12 @@ elif [ "$p_arg" == "ji" ] || [ "$p_arg" == "jiprolog" ] ; then
 	prolog='JIProlog'
 	logtalk=jiplgt$extension
 	logtalk_call="$logtalk $i_arg -n -g"
+elif [ "$p_arg" == "lvm" ] ; then
+	backend=lvm
+	prolog='LVM'
+	logtalk=lvmlgt$extension
+	logtalk_call="$logtalk $i_arg -g"
+	dot="?"
 elif [ "$p_arg" == "qp" ] || [ "$p_arg" == "qu-prolog" ] ; then
 	backend=qp
 	prolog='Qu-Prolog'
